@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: Special prereq handling
-our $VERSION = '1.86'; # VERSION
+our $VERSION = '1.87'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -83,6 +83,13 @@ sub register_prereqs
             phase => $phase,
           }, join('::', $module, 'XS') => 0 );
         }
+        if($module eq 'JSON::MaybeXS')
+        {
+          $self->zilla->register_prereqs({
+            type => 'recommends',
+            phase => $phase,
+          }, "Cpanel::JSON::XS");
+        }
         my($first) = split /::/, $module;
         if($first =~ /^(AnyEvent|Mojo|Mojolicious)$/)
         {
@@ -147,7 +154,7 @@ Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs - Special prereq handling
 
 =head1 VERSION
 
-version 1.86
+version 1.87
 
 =head1 SYNOPSIS
 
