@@ -7,7 +7,7 @@ use File::Path qw( make_path );
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '1.86'; # VERSION
+our $VERSION = '1.87'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -116,6 +116,12 @@ sub setup_installer
     }
   }
   
+  if($list{'JSON::MaybeXS'})
+  {
+    $list{'JSON::PP'}++;
+    $list{'JSON::XS'}++;
+  }
+  
   foreach my $lib (@{ $self->diag })
   {
     if($lib =~ /^-(.*)$/)
@@ -193,7 +199,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 1.86
+version 1.87
 
 =head1 SYNOPSIS
 
